function [success] = createCalibrationComponentObjects(this, ComponentName, varargin)
%CREATECALIBRATIONCOMPONENTOBJECTS creates Simulink calibration objects from AUTOSAR Calibration Component.
%
%   createCalibrationComponentObjects(IMPORTEROBJ 'COMPONENTNAME') creates the Simulink 
%   calibration objects to the AUTOSAR Calibration Component described in the XML file
%   imported by the arxml.importer object IMPORTEROBJ.
%
%   Usage:
%      [success] = createCalibrationComponentObjects(importerObj, componentName, varargin)
%
%   Inputs:
%      importerObj:   arxml.importer object
%      componentName: absolute Short-Name path of the CalPrm-Component
%      varargin:      Parameter/Value pairs. Supported parameters are:
%
%         DataDictionary: String specifying a Simulink data dictionary into
%         which to import the Simulink calibration data objects.
%
%   Outputs:
%      success: It is true if this function is successful. Otherwise, 
%               it is false.
%
%   See also arxml.importer.getCalibrationComponentNames arxml.importer.getFile 
%      arxml.importer.setFile arxml.importer.getDependencies 
%      arxml.importer.setDependencies

%   Copyright 2008-2016 The MathWorks, Inc.
%     

  
success = false; %#ok
  
% Create an instance of the inputParser class.
argParser = inputParser;   

% Add arguments to the schema
argParser.addRequired('this', @(x) isa(x, class(x)));
argParser.addRequired('ComponentName', @ischar);
argParser.addParameter('DataDictionary', '', @(x) (ischar(x)));

% parameters that are not intended to be customer visible
argParser.addParameter('CreateSimulinkObject', true, @(x)(islogical(x)||(x==1)||(x==0)));
argParser.addParameter('NameConflictAction', 'overwrite', @(x)any(strcmpi(x,{'overwrite','makenameunique','error'})));

% Read and validate each argument
argParser.parse(this, ComponentName, varargin{:});

% Check if the DataDictionary exists
autosar.mm.mm2sl.utils.checkAndCreateDD(argParser.Results.DataDictionary);

% Create the calibration objects
p_create_calib_component(this, argParser);

success = true;

% LocalWords:  IMPORTEROBJ COMPONENTNAME makenameunique pathparts
