function [modelH,success] = createCompositionAsModel(importerObj, compositionName, varargin)
%CREATECOMPOSITIONASMODEL creates an AUTOSAR Composition-Software-Component as a
%   Simulink model.

%   Copyright 2016 The MathWorks, Inc.

% parse and validate arguments
argParser = autosar.composition.mm2sl.private.ArgumentParser(compositionName, varargin{:});

% Lazy file reading
p_update_read(importerObj);
importerObj.needReadUpdate = true;

% find m3iComposition
m3iTopComposition = autosar.mm.Model.findChildByName(importerObj.arModel, compositionName);
if isempty(m3iTopComposition) || ~isa(m3iTopComposition,...
        'Simulink.metamodel.arplatform.composition.CompositionComponent')
    DAStudio.error('autosarstandard:importer:badImporterCompositionName',...
        'CompositionSwComponent', compositionName);
end

% import all the atomic software components
autosar.composition.mm2sl.AtomicSwComponentBuilder. ...
    importAllAtomicComponents(m3iTopComposition, importerObj.copy(), argParser);

% import all the composition components (bottom-up)
modelH = autosar.composition.mm2sl.CompositionSwComponentBuilder. ...
    importAllCompositionComponents(m3iTopComposition,...
    importerObj.arModel, importerObj.arSchemaVer);
success = modelH~=-1;

% LocalWords:  metamodel arplatform autosarstandard Sw
